Module: Google::Cloud::Memcache
- Defined in:
- lib/google/cloud/memcache.rb,
lib/google/cloud/memcache/version.rb
Constant Summary collapse
- VERSION =
"1.1.2"
Class Method Summary collapse
-
.cloud_memcache(version: :v1, &block) ⇒ CloudMemcache::Client
Create a new client object for CloudMemcache.
-
.configure {|::Google::Cloud.configure.memcache| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-memcache library.
Class Method Details
.cloud_memcache(version: :v1, &block) ⇒ CloudMemcache::Client
Create a new client object for CloudMemcache.
By default, this returns an instance of
Google::Cloud::Memcache::V1::CloudMemcache::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the CloudMemcache service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About CloudMemcache
Configures and manages Cloud Memorystore for Memcached instances.
The memcache.googleapis.com service implements the Google Cloud Memorystore
for Memcached API and defines the following resource model for managing
Memorystore Memcached (also called Memcached below) instances:
- The service works with a collection of cloud projects, named:
/projects/* - Each project has a collection of available locations, named:
/locations/* - Each location has a collection of Memcached instances, named:
/instances/* - As such, Memcached instances are resources of the form:
/projects/{project_id}/locations/{location_id}/instances/{instance_id}
Note that location_id must be a GCP region; for example:
projects/my-memcached-project/locations/us-central1/instances/my-memcached
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/cloud/memcache.rb', line 80 def self.cloud_memcache version: :v1, &block require "google/cloud/memcache/#{version.to_s.downcase}" package_name = Google::Cloud::Memcache .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::Memcache.const_get package_name package_module.const_get(:CloudMemcache).const_get(:Client).new(&block) end |
.configure {|::Google::Cloud.configure.memcache| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-memcache library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
119 120 121 122 123 |
# File 'lib/google/cloud/memcache.rb', line 119 def self.configure yield ::Google::Cloud.configure.memcache if block_given? ::Google::Cloud.configure.memcache end |